#
# spec file for package cpustat
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cpustat
Version:        0.02.15
Release:        bp155.1.4
Summary:        Periodic cpu utilization statistics
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://kernel.ubuntu.com/~cking/cpustat/
Source:         https://kernel.ubuntu.com/~cking/tarballs/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  ncurses-devel

%description
cpustat periodically reports the current CPU utilization of running tasks and
can optionally report per CPU and per task utilization statistics at the end
of a run.
cpustat has been designed and optimized to use a minimal amount of CPU cycles
to monitor a system hence it is a light weight alternative to traditional
process monitoring tools such as top.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Benchmark
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (cpustat and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install

%files
%license COPYING
%doc README
%{_sbindir}/cpustat
%{_mandir}/man8/cpustat.8%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Mon Jun 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.15
  * Set endptr to null to clear up pedantic static analysis
* Thu Apr 29 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.14
  * Remove update of sz as the result is never read
* Sat Nov  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.13
  * cpustat: handle case where comm field contains ) and spaces
* Thu Sep 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.12
  * cpustat: fix truncated output, allow CPU %% stats > 100%%
- Update to version 0.02.11
  * cpustat: zero ws struct to clear static analysis warnings
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Drop SLE12 compat ifdef
* Fri Feb 28 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.10
  * Makefile: add bash-completion to make dist rule
  * Add bash completion script
- Add subpackage for bash-completion
* Tue Jul 30 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.09
  * Makefile: bump version
  * Makefile: remove -g flag
  * Avoid division by zero if total is zero
* Fri Jul 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.02.08
  * Makefile: bump version
  * Fix strncpy string size
  * Reduce scope of variable i
  * Update copyright year
* Sat Jan 12 2019 mardnh@gmx.de
- Update to version 0.02.07
  * Re-arrange fields in structs to pack data more efficiently
- Update to version 0.02.06
  * Don't show CPU frequency if it cannot be read
* Wed Sep  5 2018 liedke@rz.uni-mannheim.de
- update to version 0.02.05
  * Fix leading zeros on time data
  * Fix the time scaling, use base 60 where necessary
  * Add more constifcations to functions and arrays
  * Minor code clean ups
  * constify cpu_freq_scale
  * voidify function returns
  * debian/control: set debhelper version >= 11
  * debian/compat: set to 11
  * debian/control: remove empty line at end of file
  * debian/copyright: use secure URI
  * Makefile: bump version
* Wed Jan 31 2018 mardnh@gmx.de
- update to version 0.02.04
  * Makefile: bump version
  * Manual: update copyright year and manual date
  * Add variable pid size handling.
  * Voidify close/fclose calls
* Wed May 10 2017 mardnh@gmx.de
- update to version 0.02.03
  * Makefile: bump version
  * Manual: update copyright year and manual date
  * Add variable pid size handling.
  * Voidify close/fclose calls
- update to version 0.02.02
  * Makefile: bump version
  * Remove some redundant pointer increments
  * Update copyright year
  * Add libncursesw5-dev to snapcraft yaml
  * Don't do a resize() in SIGWINCH signal handler
- update to version 0.02.01
  * Makefile: bump version
  * Remove df_putc, we don't use it now
  * Minor cleanup, add more comments
  * Remove another slow snprintf in cpu_freq_format
  * Generalise putdouble_point1 to n decimal places, rename putdec to putint
  * Remove another snprintf from proc_stat_dump
  * Add command and spacing before Freq Avg text
  * Remove another use of expensive sprintf
  * Add putuint helper and remove another overly used snprintf
  * Fix incorrect closing square bracket around kernel thread
  * Remove another snprintf and replace with more optimal code
  * Add some minor optimisations
  * Optimise printing so we don't use printf which is expensive
  * Add comments to putdec function
  * Generalise putdec function to handle any decimal sized string
  * Use inline popcount to count bits
  * Ensure in top mode we don't fall off bottom of terminal
- update to version 0.02.00
  * Makefile: bump version to 0.02.00
  * Debian control: add libncurses5-dev to Build-Depends
  * Fix timestamp output
  * Retry select sleep if we have some pending sleep time
  * Minor reworking to handle optimal refreshing and size refetching
  * Default winsize if we can't fetch it, and fetch size on setup
  * Handle display modes using display_function_t handlers
  * Add -X top like mode
  * Ensure large integer constant is ULL
- update to version 0.01.29
  * Makefile: bump version
  * Fix variable shadowing on variable duration
  * Use FLOAT_CMP helper macro to perform slop on float compares
  * Constify variables in sort compare helper
  * Makefile: add PEDANTIC build flags
- update to version 0.01.28
  * Makefile: bump version
  * Makefile: add mascot and snapcraft directories to make dist rule
  * cpustat: only add pid info to hash table if it is new (LP: #1631050)
  * snapcraft: Makefile: fix removal errors of snap files
  * snapcraft: Makefile: add auto versioning
  * snapcraft.yaml: add build-packages
  * Add snapcraft Makefile
  * Add cpustat pngs
  * mascot: small resize to ensure it scales perfectly to 128x128
  * Add cpustat mascot
* Sat Jul 30 2016 mardnh@gmx.de
- update to version 0.01.27
  * Makefile: bump version
  * debian/control: update standards version to 3.9.8
- update to version 0.01.26
  * Makefile: bump version
  * Update date in manual
  * debian/control: update standards version to 3.9.7
  * Fix spelling mistake in manual, onlt -> only
  * Update copyright year to 2016
* Wed Nov 11 2015 mardnh@gmx.de
- initial package
